@@ -1,8 +1,13 @@
-from flask import flash, redirect, url_for
-from flask_login import current_user
 from functools import wraps
 
+from flask import flash
+from flask import redirect
+from flask import url_for
+
+from flask_login import current_user
+
 from shopyoapi.init import login_manager
+
 from modules.admin.models import User
 
 login_manager.login_view = "login.login"
@@ -17,10 +22,10 @@ def load_user(id):
 def admin_required(f):
     @wraps(f)
     def wrap(*args, **kwargs):
-        if current_user.admin_user is True:
+        if current_user.is_admin is True:
             return f(*args, **kwargs)
         else:
             flash("You need to be an admin to view this page.")
-            return redirect(url_for("category.category"))
+            return redirect(url_for("control_panel.index"))
 
     return wrap
