@@ -1,13 +1,13 @@
-import os
 import json
+import os
 
 from flask import Blueprint
-from flask import render_template
-from flask_login import login_required
-from flask import flash
 from flask import current_app
+from flask import flash
+from flask import render_template
+
+from flask_login import login_required
 
-from shopyoapi.enhance import base_context
 from shopyoapi.html import notify_success
 
 control_panel_blueprint = Blueprint(
@@ -18,19 +18,29 @@ control_panel_blueprint = Blueprint(
 )
 all_info = {}
 
+
 @control_panel_blueprint.route("/")
 @login_required
 def index():
-    context = base_context()
+    context = {}
 
-    for module in os.listdir(os.path.join(current_app.config['BASE_DIR'], "modules")):
+    for module in os.listdir(
+        os.path.join(current_app.config["BASE_DIR"], "modules")
+    ):
         if module.startswith("__"):
             continue
         if module not in ["control_panel"]:
-            with open(os.path.join(current_app.config['BASE_DIR'], 'modules', module, 'info.json')) as f:
+            with open(
+                os.path.join(
+                    current_app.config["BASE_DIR"],
+                    "modules",
+                    module,
+                    "info.json",
+                )
+            ) as f:
                 module_info = json.load(f)
                 all_info[module] = module_info
 
     context["all_info"] = all_info
-    flash(notify_success('Notif test'))
+    flash(notify_success("Notif test"))
     return render_template("control_panel/index.html", **context)
