@@ -1,24 +1,24 @@
-import os
 import json
+import os
 
 from flask import Blueprint
 from flask import render_template
-from flask_login import login_required
 
-from shopyoapi.enhance import base_context
+from flask_login import login_required
 
 internals_blueprint = Blueprint(
     "internals",
     __name__,
-    url_prefix='/internals',
+    url_prefix="/internals",
     template_folder="templates",
 )
 all_info = {}
 
+
 @internals_blueprint.route("/")
 @login_required
 def index():
-    context = base_context()
+    context = {}
 
     for module in os.listdir("modules"):
         if module.startswith("__"):
