@@ -1,12 +1,26 @@
-from shopyoapi.html import notify_warning
 from flask import flash
 
+from shopyoapi.html import notify_warning
+
+
 def flash_errors(form):
-    """Flashes form errors"""
+    """
+    Auto flash errors from WKHtml forms
+    Reqwires base module or similar notification
+    mechanism
+
+    Parameters
+    ----------
+    form: WKHtml form
+
+    Returns
+    -------
+    None
+    """
     for field, errors in form.errors.items():
         for error in errors:
             error_msg = u"Error in the %s field - %s" % (
                 getattr(form, field).label.text,
-                error
+                error,
             )
-            flash(notify_warning(error_msg))
\ No newline at end of file
+            flash(notify_warning(error_msg))
